@@ -22,11 +22,11 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
        no Sjis; ͗pł܂B
 
     R}hvvgňȉ̂悤Ɏs
-      perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
-      perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
-      perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
-      perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
-      perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
+      perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
 
       ? * găChJ[h̎w肪ł܂
       ' ` ' găNH[g邱Ƃł܂
@@ -87,6 +87,7 @@ hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
 LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B̂
 UTF8 tO͂܂B
 
+Gȉ@͖蕡Gɂ܂B
 ȂGR[h̖肩GXP[v܂񂩁H
 
 =head1 ЂƂ̖
@@ -123,7 +124,7 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
 =item * ߋ̃f[^AXNvgAmEnEƌ݊ۂĂ
 
-=item * Sjis.pm  Esjis.pm ŋ@\(̃W[ȂƂ܂)
+=item * UNIXOSADOSOS̏ꍇ́ASjis.pm  Esjis.pm ŋ@\
 
 =item * UTF8 tOȂł(perlunitut  perluniadvice ̑Ή͕sv)
 
@@ -761,6 +762,17 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
  (l '1' ͈ӖȂ̂ŉł\܂)
 
+=head1 MacJPerl ̋@\
+
+ } Web ̏Qlɂ MacOS ɑΉĂ݂܂B@Ȃ߂ɃeXg
+ łĂ܂B񍐁AoO񍐓ƂƂĂ肪łB
+ 
+ sɂ͈ȉ̃\tgEFAKvłB
+ 1. MacPerl W[
+ 2. Mac::Files W[
+ 3. ToolServer
+ 4. MPW(Macintosh Programmer's Workshop)
+
 =head1 oOƐ
 
 oO񍐁Apb`}܂B
@@ -1377,6 +1389,22 @@ Unicode T|[g perl ɓȑÓAeq Zq́A2̃XJ[ϐɂ
 ĕ\ꂽoCgׂĂ܂Bperl5.8 ȍ~Aeq ́A2̃oCgׂ
 Ɠ UTF8 tOl܂B
 
+  perl5.8 ȍ~̏񏈗f
+ 
+    +----------------------+---------------------+
+    |    eLXgf[^    |                     |
+    +----------+-----------|   oCif[^    |
+    |   UTF8   |  Latin-1  |                     |
+    +----------+-----------+---------------------+
+    | UTF8     |            UTF8                 |
+    | tOON |            tO OFF           |
+    +--------------------------------------------+
+    http://perl-users.jp/articles/advent-calendar/2010/casual/4
+ 
+    ̐}oȂƃvO܂B
+ 
+    (ǂ Latin-1 ʈ̂ł傤H)
+
 ʓIɂ̕ύX́Aߋ̃XNvgƐVXNvg̊Ԃɑ傫ȍa܂B
 ͂◼҂̃XNvg̓R[h݂ɍėp邱Ƃł܂B܂V@
 vO}ɕS邽߁AXNvgׂĒû͂܂܂
@@ -1389,6 +1417,19 @@ V@ŖƂȂĂ邱Ƃ UTF8 tO͎ۂ̕̕ƈvȂ
 Ő̂̕@ɖ߂ƂɂāAǂ̂悤ɉ̂ Programming Perl, 3rd ed.
 (M vO~OPerl 3) 402y[Wxp܂傤B
 
+  Sjis\tgEFApɂ񏈗f
+ 
+    +-----------------------------------+
+    |            INebg           | oCif[^
+    +-----------------------------------+
+    |                             | eLXgf[^
+    +-----------------------------------+
+    |       ASCII ݊̕      | ShiftJIS Ȃ
+    +-----------------------------------+
+              (UTF8tOȂ)
+ 
+    ̐}ɈӖ͂Ȃ߁AoKv܂B
+
 zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 
 =over 2
@@ -1489,6 +1530,7 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 =item * S[5
 
     JPerl [U Perl  JPerl ێł悤ɂȂB
+    邢 MacJPerl [U MacPerl  MacJPerl ێł悤ɂȂB
 
     JPerl Ȃ̂΂ɂ܂悤 ...
 
@@ -1562,7 +1604,7 @@ vO~O񋟂܂B
 
  {񏈗
  Understanding Japanese Information Processing
- By Ken Lunde, tՐ, ؕ 
+ By Ken Lunde, t ,   
  1995N8 s
  496y[W
  ISBN 4-89052-708-7
@@ -1603,7 +1645,7 @@ vO~O񋟂܂B
  http://www.context.co.jp/~cond/books/old-books.html
 
  JIST
- Ŗki Ғ
+ Ŗ ki Ғ
  1456 
  ISBN 4-542-20129-5
  http://www.webstore.jsa.or.jp/lib/lib.asp?fn=/manual/mnl01_12.htm
@@ -1614,6 +1656,24 @@ vO~O񋟂܂B
  T1008901080816 G08901-8
  http://ascii.asciimw.jp/books/magazines/unix.shtml
 
+ MacPerl
+ Vicki Brown, Chris Nandor , ()RXEvlbg 
+ 1999N03 s
+ 399y[W
+ ISBN 4-7561-3068-2
+
+ Macintoshf[^pp
+ Γc L 
+ 230y[W
+ 1995N2 s
+ ISBN 4-89563-408-6
+
+ MPWvO~Ou
+ Handmade Intelligence 
+ 1992N8 s
+ 346y[W
+ ISBN 4-7561-0963-2
+
  Sjis \tgEFAt@~[
  http://search.cpan.org/dist/Big5HKSCS/
  http://search.cpan.org/dist/Big5Plus/
@@ -1678,6 +1738,9 @@ vO~O񋟂܂B
  http://search.cpan.org/~watanabe/
  ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
+ Chuck Houpt,  qq, MacJPerl
+ http://habilis.net/macjperl/index.j.html
+
  Ί_ ꂳ, Pod-PerldocJp, _Perl̐Eւ悤
  http://search.cpan.org/dist/Pod-PerldocJp/
  http://gihyo.jp/dev/serial/01/modern-perl/0031
@@ -1702,7 +1765,7 @@ vO~O񋟂܂B
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html
 
- ruby-list (݂ 404 Not Found ɂȂĂ܂)
+ ruby-list
  http://blade.nagaokaut.ac.jp/ruby/ruby-list/index.shtml
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2440
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2446
